PO4A-HEADER: mode=after; position=FÖRFATTARE; beginboundary=\.SH
.SH ÖVERSÄTTARE
Denna manualsida har översatts av Daniel Nylander <po@danielnylander.se> 
den 31 oktober 2005.

Om du hittar några felaktigheter i översättningen, vänligen skicka ett 
e-postmeddelande till översÃ¤ttaren eller till e-postlistan
.nh
<\fIdebian\-l10n\-swedish@lists.debian.org\fR> eller <\fItp-sv@listor.tp-sv.se\fR>
.hy

